@@ -1,7 +1,7 @@
 package Mojo::Webqq;
 use strict;
 use Carp ();
-$Mojo::Webqq::VERSION = "2.0.1";
+$Mojo::Webqq::VERSION = "2.0.2";
 use Mojo::Webqq::Base 'Mojo::EventEmitter';
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -79,6 +79,7 @@ has is_polling              => 0;
 has ua_retry_times          => 5;
 has is_first_login          => -1;
 has login_state             => "init";#init|relogin|success|scaning|confirming
+has qrcode_upload_url       => undef;
 has qrcode_count            => 0;
 has qrcode_count_max        => 10;
 has send_failure_count      => 0;
@@ -237,13 +238,16 @@ sub new {
     $self->check_pid();
     $self->save_state();
     $SIG{CHLD} = 'IGNORE';
-    $SIG{INT} = $SIG{KILL} = $SIG{TERM} = sub{
+    $SIG{INT} = $SIG{TERM} = $SIG{HUP} = sub{
         return if $^O ne 'MSWin32' and $_[0] eq 'INT' and !-t;
         $self->info("捕获到停止信号[$_[0]]，准备停止...");
-        $self->clean_qrcode();
-        $self->clean_pid();
         $self->stop();
     };
+    $self->on(stop=>sub{
+        my $self = shift;
+        $self->clean_qrcode();
+        $self->clean_pid();
+    });
     $self->on(state_change=>sub{
         my $self = shift;
         $self->save_state();
