@@ -16,14 +16,15 @@ sub Mojo::Webqq::Model::_get_user_info{
         return undef unless defined $json;
         return undef if $json->{retcode} !=0;
         my $user = $json->{result};
-        $user->{state} = $self->state;
+        $user->{state} = $self->mode;
+        $user->{name} = delete $user->{nick};
         $user->{client_type} = 'web';
         $user->{birthday} = join( "-", @{ $user->{birthday} }{qw(year month day)} );
         $user->{signature} = delete $user->{lnick};
-        #my $single_long_nick = $self->get_single_long_nick( $self->qq );
+        $user->{sex} = delete $user->{gender};
+        #my $single_long_nick = $self->get_single_long_nick( $self->uid );
         #$json->{result}{signature} = $single_long_nick if defined $single_long_nick;
-        $self->reform_hash($user);
-        $user->{qq}        = $self->qq;
+        $user->{uid}       = $self->uid;
         $user->{id}        = delete $user->{uin};
         return $user;
     };
